==> downloads.html?file=gigkalender_v1.2.75_017.zip: gigkalender/admin/showUsers.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
  echo '<p class="Headline">'.$L_Headline02.'</p>';
  if ( !IsUserAdmin() ) { echo $L_015; }
  else
  {
    // Inhalt hier einfuegen
      // Datensatz-Ausgabe festlegen
        $SQL_Befehl = "SELECT * FROM ".$prefix."user order by UserName";
      // Saemtliche Datensatz-Ausgabe durchfuehren
        $resultat = mysqli_query($db, $SQL_Befehl);
      echo '<table id="WideTable" summary="Tabelle_Zeige-alle-User">
              <colgroup>
                <col class="SpalteIcon" />
                <col class="SpalteIcon" />
                <col />
                <col />
                <col />
                <col />
                <col />
                <col />
                <col class="SpalteIcon TabellenSpalte_Rechts" />
            </colgroup>
      	    <tr>
              <th>&nbsp;</th>
              <th>&nbsp;</th>
          	  <th>'.$L_UserName.'</th>
          	  <th>'.$L_UserStatus.'</th>
          	  <th>'.$L_UserPassword.'</th>
              <th>'.$L_UserEmailadress.'</th>
              <th>'.$L_UserLastActivity.'</th>
              <th>'.$L_Rights.'</th>
          	  <th>&nbsp;</th>
      	    </tr>';
      while ($row = mysqli_fetch_array($resultat))
      {
        extract($row);
        echo '<tr><td>';
        if ($UserID!=getCurrentUserVar('UserID')) {
          echo '<a href="index.php?submenue=admin&amp;inhalt=delUser&amp;uid='.$UserName.'">
                  <img src="images/delete.gif" alt="'.$L_009.'" title="'.$L_009.'" /></a>'; }
          echo '</td>
                <td>
                  <a href="index.php?submenue=admin&amp;inhalt=addUser&amp;job=edit&amp;uid='.$UserName.'">
                    <img src="images/edit.gif" alt="'.$L_010.'" title="'.$L_010.'" /></a>
                </td>
                <td>'.$UserName.'</td>
                <td>'.$UserStatus.'</td>
                <td>'; echo transformPassword($UserCurrentPassword); echo '</td>
                <td>'.$UserEmailadress.'</td>
                <td style="white-space: nowrap;">'.DatumMitUhrzeitAusTimestamp(getUserVar ($UserName, 'UserLastActivityTimestamp')).'</td>
                <td>';
        if ($UserRightEmail == 1) { echo '<img src="images/exist.gif" title="'.$L_UserRightEmail.'" alt="'.$L_UserRightEmail.'" />'; }
          else { echo '<img src="images/dontexist.gif" title="'.$L_UserRightEmail.'" alt="'.$L_UserRightEmail.'" />'; }
        if ($UserRightAddNews == 1) { echo '<img src="images/exist.gif" title="'.$L_UserRightAddNews.'" alt="'.$L_UserRightAddNews.'" />'; }
          else { echo '<img src="images/dontexist.gif" title="'.$L_UserRightAddNews.'" alt="'.$L_UserRightAddNews.'" />'; }
        if ($UserRightEditNews == 1) { echo '<img src="images/exist.gif" title="'.$L_UserRightEditNews.'" alt="'.$L_UserRightEditNews.'" />'; }
          else { echo '<img src="images/dontexist.gif" title="'.$L_UserRightEditNews.'" alt="'.$L_UserRightEditNews.'" />'; }
        if ($UserRightDeleteNews == 1) { echo '<img src="images/exist.gif" title="'.$L_UserRightDeleteNews.'" alt="'.$L_UserRightDeleteNews.'" />'; }
          else { echo '<img src="images/dontexist.gif" title="'.$L_UserRightDeleteNews.'" alt="'.$L_UserRightDeleteNews.'" />'; }
        echo '</td>
              <td>';
        if ($UserSession == "") { echo '<img src="images/user_offline.gif" title="'.$L_UserSessionOffline.'" alt="'.$L_UserSessionOffline.'" />'; }
          else { echo '<img src="images/user_online.gif" title="'.$L_UserSessionOnline.'" alt="'.$L_UserSessionOnline.'" />'; }
        echo '</td>
            </tr>';
        }
        echo '</table>
              <a href="index.php?submenue=admin&amp;inhalt=addUser&amp;job=add">
                <img src="images/add.gif" alt="'.$L_001.'" title="'.$L_001.'" /></a>';
        // Inhalt zuende
  }
?>

==> downloads.html?file=gigkalender_v1.2.80_040.zip: gigkalender/admin/showUsers.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
  echo '<p class="Headline">'.$L_Headline02.'</p>';
  if ( !IsUserAdmin() ) { echo $L_015; }
  else
  {
    // Inhalt hier einfuegen
      // Datensatz-Ausgabe festlegen
        $SQL_Befehl = "SELECT * FROM ".$prefix."user order by UserName";
      // Saemtliche Datensatz-Ausgabe durchfuehren
        $resultat = mysqli_query($db, $SQL_Befehl);
      echo '<table id="WideTable" summary="Tabelle_Zeige-alle-User">
              <colgroup>
                <col class="SpalteIcon" />
                <col class="SpalteIcon" />
                <col />
                <col />
                <col />
                <col />
                <col />
                <col />
                <col class="SpalteIcon TabellenSpalte_Rechts" />
            </colgroup>
      	    <tr>
              <th>&nbsp;</th>
              <th>&nbsp;</th>
          	  <th>'.$L_UserName.'</th>
          	  <th>'.$L_UserStatus.'</th>
          	  <th>'.$L_UserPassword.'</th>
              <th>'.$L_UserEmailadress.'</th>
              <th>'.$L_UserLastActivity.'</th>
              <th>'.$L_Rights.'</th>
          	  <th>&nbsp;</th>
      	    </tr>';
      while ($row = mysqli_fetch_array($resultat))
      {
        extract($row);
        echo '<tr><td>';
        if ($UserID!=getCurrentUserVar('UserID')) {
          echo '<a href="index.php?submenue=admin&amp;content=delUser&amp;uid='.$UserName.'">
                  <img src="images/delete.gif" alt="'.$L_009.'" title="'.$L_009.'" /></a>'; }
          echo '</td>
                <td>
                  <a href="index.php?submenue=admin&amp;content=addUser&amp;job=edit&amp;uid='.$UserName.'">
                    <img src="images/edit.gif" alt="'.$L_010.'" title="'.$L_010.'" /></a>
                </td>
                <td>'.$UserName.'</td>
                <td>'.$UserStatus.'</td>
                <td>********</td>
                <td>'.$UserEmailadress.'</td>
                <td style="white-space: nowrap;">'.DatumMitUhrzeitAusTimestamp(getUserVar ($UserName, 'UserLastActivityTimestamp')).'</td>
                <td>';
        if ($UserRightEmail == 1) { echo '<img src="images/exist.gif" title="'.$L_UserRightEmail.'" alt="'.$L_UserRightEmail.'" />'; }
          else { echo '<img src="images/dontexist.gif" title="'.$L_UserRightEmail.'" alt="'.$L_UserRightEmail.'" />'; }
        if ($UserRightAddNews == 1) { echo '<img src="images/exist.gif" title="'.$L_UserRightAddNews.'" alt="'.$L_UserRightAddNews.'" />'; }
          else { echo '<img src="images/dontexist.gif" title="'.$L_UserRightAddNews.'" alt="'.$L_UserRightAddNews.'" />'; }
        if ($UserRightEditNews == 1) { echo '<img src="images/exist.gif" title="'.$L_UserRightEditNews.'" alt="'.$L_UserRightEditNews.'" />'; }
          else { echo '<img src="images/dontexist.gif" title="'.$L_UserRightEditNews.'" alt="'.$L_UserRightEditNews.'" />'; }
        if ($UserRightDeleteNews == 1) { echo '<img src="images/exist.gif" title="'.$L_UserRightDeleteNews.'" alt="'.$L_UserRightDeleteNews.'" />'; }
          else { echo '<img src="images/dontexist.gif" title="'.$L_UserRightDeleteNews.'" alt="'.$L_UserRightDeleteNews.'" />'; }
        echo '</td>
              <td>';
        if ($UserSession == "") { echo '<img src="images/user_offline.gif" title="'.$L_UserSessionOffline.'" alt="'.$L_UserSessionOffline.'" />'; }
          else { echo '<img src="images/user_online.gif" title="'.$L_UserSessionOnline.'" alt="'.$L_UserSessionOnline.'" />'; }
        echo '</td>
            </tr>';
        }
        echo '</table>
              <a href="index.php?submenue=admin&amp;content=addUser&amp;job=add">
                <img src="images/add.gif" alt="'.$L_001.'" title="'.$L_001.'" /></a>';
        // Inhalt zuende
  }
?>
